from typing import Tuple, Set, Iterable, List

class FileReferenceStatus:
    Unknown = 0
    FullPathValid = 1
    FileNotFound = 2
class FileFindPreference:
    None = 0
    FullPath = 1
    RelativePath = 2
    BasePath = 3
    ContentMatch = 4
    MostRecent = 5
class FileObj:
    def Write (filename : str, doc : RhinoDoc, options : FileObjWriteOptions) -> WriteFileResult: ...
    def Write (stream : StreamWriter, doc : RhinoDoc, options : FileObjWriteOptions) -> WriteFileResult: ...
    def Write (filename : str, meshes : Set(Mesh), options : FileObjWriteOptions) -> WriteFileResult: ...
    def Read (filename : str, doc : RhinoDoc, options : FileObjReadOptions) -> bool: ...
class FileObjWriteOptions:
    def __init__(self, writeOptions : FileWriteOptions): ...
    @property
    def ActualFilePathOnMac (self) -> str: ...
    @ActualFilePathOnMac.setter
    def ActualFilePathOnMac (self, value : str) -> None: ...
    @property
    def EolType (self) -> AsciiEol: ...
    @EolType.setter
    def EolType (self, value : AsciiEol) -> None: ...
    @property
    def TrimCurveType (self) -> CurveType: ...
    @TrimCurveType.setter
    def TrimCurveType (self, value : CurveType) -> None: ...
    @property
    def ObjectType (self) -> GeometryType: ...
    @ObjectType.setter
    def ObjectType (self, value : GeometryType) -> None: ...
    @property
    def ExportObjectNames (self) -> ObjObjectNames: ...
    @ExportObjectNames.setter
    def ExportObjectNames (self, value : ObjObjectNames) -> None: ...
    @property
    def ExportGroupNameLayerNames (self) -> ObjGroupNames: ...
    @ExportGroupNameLayerNames.setter
    def ExportGroupNameLayerNames (self, value : ObjGroupNames) -> None: ...
    @property
    def ExportMaterialDefinitions (self) -> bool: ...
    @ExportMaterialDefinitions.setter
    def ExportMaterialDefinitions (self, value : bool) -> None: ...
    @property
    def MapZtoY (self) -> bool: ...
    @MapZtoY.setter
    def MapZtoY (self, value : bool) -> None: ...
    @property
    def SignificantDigits (self) -> int: ...
    @SignificantDigits.setter
    def SignificantDigits (self, value : int) -> None: ...
    @property
    def WrapLongLines (self) -> bool: ...
    @WrapLongLines.setter
    def WrapLongLines (self, value : bool) -> None: ...
    @property
    def MergeNestedGroupingNames (self) -> bool: ...
    @MergeNestedGroupingNames.setter
    def MergeNestedGroupingNames (self, value : bool) -> None: ...
    @property
    def SortObjGroups (self) -> bool: ...
    @SortObjGroups.setter
    def SortObjGroups (self, value : bool) -> None: ...
    @property
    def MeshType (self) -> VertexWelding: ...
    @MeshType.setter
    def MeshType (self, value : VertexWelding) -> None: ...
    @property
    def SubDMeshType (self) -> SubDMeshing: ...
    @SubDMeshType.setter
    def SubDMeshType (self, value : SubDMeshing) -> None: ...
    @property
    def CreateNgons (self) -> bool: ...
    @CreateNgons.setter
    def CreateNgons (self, value : bool) -> None: ...
    @property
    def IncludeUnweldedEdgesInNgons (self) -> bool: ...
    @IncludeUnweldedEdgesInNgons.setter
    def IncludeUnweldedEdgesInNgons (self, value : bool) -> None: ...
    @property
    def CullUnnecessaryVertexesInNgons (self) -> bool: ...
    @CullUnnecessaryVertexesInNgons.setter
    def CullUnnecessaryVertexesInNgons (self, value : bool) -> None: ...
    @property
    def MinNgonFaceCount (self) -> int: ...
    @MinNgonFaceCount.setter
    def MinNgonFaceCount (self, value : int) -> None: ...
    @property
    def ExportTcs (self) -> bool: ...
    @ExportTcs.setter
    def ExportTcs (self, value : bool) -> None: ...
    @property
    def ExportNormals (self) -> bool: ...
    @ExportNormals.setter
    def ExportNormals (self, value : bool) -> None: ...
    @property
    def ExportVcs (self) -> bool: ...
    @ExportVcs.setter
    def ExportVcs (self, value : bool) -> None: ...
    @property
    def ExportOpenMeshes (self) -> bool: ...
    @ExportOpenMeshes.setter
    def ExportOpenMeshes (self, value : bool) -> None: ...
    @property
    def UnderbarMaterialNames (self) -> bool: ...
    @UnderbarMaterialNames.setter
    def UnderbarMaterialNames (self, value : bool) -> None: ...
    @property
    def UseSimpleDialog (self) -> bool: ...
    @UseSimpleDialog.setter
    def UseSimpleDialog (self, value : bool) -> None: ...
    @property
    def MeshParameters (self) -> MeshingParameters: ...
    @MeshParameters.setter
    def MeshParameters (self, value : MeshingParameters) -> None: ...
    @property
    def UseRelativeIndexing (self) -> bool: ...
    @UseRelativeIndexing.setter
    def UseRelativeIndexing (self, value : bool) -> None: ...
    @property
    def SubDSurfaceMeshingDensity (self) -> int: ...
    @SubDSurfaceMeshingDensity.setter
    def SubDSurfaceMeshingDensity (self, value : int) -> None: ...
    def GetTransform (self) -> Transform: ...
class FileObjReadOptions:
    def __init__(self, readOptions : FileReadOptions): ...
    @property
    def UseObjGroupsAs (self) -> UseObjGsAs: ...
    @UseObjGroupsAs.setter
    def UseObjGroupsAs (self, value : UseObjGsAs) -> None: ...
    @property
    def UseObjObjects (self) -> bool: ...
    @UseObjObjects.setter
    def UseObjObjects (self, value : bool) -> None: ...
    @property
    def MapYtoZ (self) -> bool: ...
    @MapYtoZ.setter
    def MapYtoZ (self, value : bool) -> None: ...
    @property
    def MorphTargetOnly (self) -> bool: ...
    @MorphTargetOnly.setter
    def MorphTargetOnly (self, value : bool) -> None: ...
    @property
    def ReverseGroupOrder (self) -> bool: ...
    @ReverseGroupOrder.setter
    def ReverseGroupOrder (self, value : bool) -> None: ...
    @property
    def IgnoreTextures (self) -> bool: ...
    @IgnoreTextures.setter
    def IgnoreTextures (self, value : bool) -> None: ...
    @property
    def DisplayColorFromObjMaterial (self) -> bool: ...
    @DisplayColorFromObjMaterial.setter
    def DisplayColorFromObjMaterial (self, value : bool) -> None: ...
    @property
    def Split32BitTextures (self) -> bool: ...
    @Split32BitTextures.setter
    def Split32BitTextures (self, value : bool) -> None: ...
    def GetTransform (self) -> Transform: ...
class FilePdfEventArgs:
    @property
    def Pdf (self) -> FilePdf: ...
class FilePdf:
    def add_PreWrite (value : EventHandler) -> None: ...
    def remove_PreWrite (value : EventHandler) -> None: ...
    def Create () -> FilePdf: ...
    def AddPage (self, settings : ViewCaptureSettings) -> int: ...
    def AddPage (self, widthInDots : int, heightInDots : int, dotsPerInch : int) -> int: ...
    def DrawText (self, pageNumber : int, text : str, x : float, y : float, heightPoints : Single, onfont : Font, fillColor : Color, strokeColor : Color, strokeWidth : Single, angleDegrees : Single, horizontalAlignment : TextHorizontalAlignment, verticalAlignment : TextVerticalAlignment) -> None: ...
    def DrawPolyline (self, pageNumber : int, polyline : Set(PointF), fillColor : Color, strokeColor : Color, strokeWidth : Single) -> None: ...
    def DrawLine (self, pageNumber : int, from_ : PointF, to : PointF, strokeColor : Color, strokeWidth : Single) -> None: ...
    def DrawBitmap (self, pageNumber : int, bitmap : Bitmap, left : Single, top : Single, width : Single, height : Single, rotationInDegrees : Single) -> None: ...
    def Write (self, filename : str) -> None: ...
    def Write (self, stream : Stream) -> None: ...
    def PdfDocumentImplementation (self) -> Object: ...
class FilePly:
    def Write (filename : str, doc : RhinoDoc, options : FilePlyWriteOptions) -> WriteFileResult: ...
class FilePlyWriteOptions:
    def __init__(self, writeOptions : FileWriteOptions): ...
    @property
    def UseSimpleDialog (self) -> bool: ...
    @UseSimpleDialog.setter
    def UseSimpleDialog (self, value : bool) -> None: ...
    @property
    def ExportASCII (self) -> bool: ...
    @ExportASCII.setter
    def ExportASCII (self, value : bool) -> None: ...
    @property
    def ExportNormals (self) -> bool: ...
    @ExportNormals.setter
    def ExportNormals (self, value : bool) -> None: ...
    @property
    def ExportColors (self) -> bool: ...
    @ExportColors.setter
    def ExportColors (self, value : bool) -> None: ...
    @property
    def ExportMaterial (self) -> bool: ...
    @ExportMaterial.setter
    def ExportMaterial (self, value : bool) -> None: ...
    @property
    def MeshingParameters (self) -> MeshingParameters: ...
    @MeshingParameters.setter
    def MeshingParameters (self, value : MeshingParameters) -> None: ...
class FileSlc:
    def Write (filename : str, doc : RhinoDoc, options : FileSlcWriteOptions) -> bool: ...
class FileSlcWriteOptions:
    def __init__(self): ...
    @property
    def StartPoint (self) -> Point3d: ...
    @StartPoint.setter
    def StartPoint (self, value : Point3d) -> None: ...
    @property
    def EndPoint (self) -> Point3d: ...
    @EndPoint.setter
    def EndPoint (self, value : Point3d) -> None: ...
    @property
    def SliceDistance (self) -> float: ...
    @SliceDistance.setter
    def SliceDistance (self, value : float) -> None: ...
    @property
    def UseMeshes (self) -> bool: ...
    @UseMeshes.setter
    def UseMeshes (self, value : bool) -> None: ...
    @property
    def AngleBetweenSegmentsDegrees (self) -> float: ...
    @AngleBetweenSegmentsDegrees.setter
    def AngleBetweenSegmentsDegrees (self, value : float) -> None: ...
class FileStp:
    def Write (filename : str, doc : RhinoDoc, options : FileStpWriteOptions) -> bool: ...
class FileStpWriteOptions:
    def __init__(self): ...
    @property
    def Export2dCurves (self) -> bool: ...
    @Export2dCurves.setter
    def Export2dCurves (self, value : bool) -> None: ...
    @property
    def ExportBlack (self) -> bool: ...
    @ExportBlack.setter
    def ExportBlack (self, value : bool) -> None: ...
    @property
    def SplitClosedSurfaces (self) -> bool: ...
    @SplitClosedSurfaces.setter
    def SplitClosedSurfaces (self, value : bool) -> None: ...
class ImageFile:
    def SupportsAlphaChannel (filename : str) -> bool: ...
class File3dmSettings:
    @property
    def ModelUrl (self) -> str: ...
    @ModelUrl.setter
    def ModelUrl (self, value : str) -> None: ...
    @property
    def ModelBasepoint (self) -> Point3d: ...
    @ModelBasepoint.setter
    def ModelBasepoint (self, value : Point3d) -> None: ...
    @property
    def ModelAbsoluteTolerance (self) -> float: ...
    @ModelAbsoluteTolerance.setter
    def ModelAbsoluteTolerance (self, value : float) -> None: ...
    @property
    def ModelAngleToleranceRadians (self) -> float: ...
    @ModelAngleToleranceRadians.setter
    def ModelAngleToleranceRadians (self, value : float) -> None: ...
    @property
    def ModelAngleToleranceDegrees (self) -> float: ...
    @ModelAngleToleranceDegrees.setter
    def ModelAngleToleranceDegrees (self, value : float) -> None: ...
    @property
    def ModelRelativeTolerance (self) -> float: ...
    @ModelRelativeTolerance.setter
    def ModelRelativeTolerance (self, value : float) -> None: ...
    @property
    def PageAbsoluteTolerance (self) -> float: ...
    @PageAbsoluteTolerance.setter
    def PageAbsoluteTolerance (self, value : float) -> None: ...
    @property
    def PageAngleToleranceRadians (self) -> float: ...
    @PageAngleToleranceRadians.setter
    def PageAngleToleranceRadians (self, value : float) -> None: ...
    @property
    def PageAngleToleranceDegrees (self) -> float: ...
    @PageAngleToleranceDegrees.setter
    def PageAngleToleranceDegrees (self, value : float) -> None: ...
    @property
    def PageRelativeTolerance (self) -> float: ...
    @PageRelativeTolerance.setter
    def PageRelativeTolerance (self, value : float) -> None: ...
    @property
    def ModelUnitSystem (self) -> UnitSystem: ...
    @ModelUnitSystem.setter
    def ModelUnitSystem (self, value : UnitSystem) -> None: ...
    @property
    def PageUnitSystem (self) -> UnitSystem: ...
    @PageUnitSystem.setter
    def PageUnitSystem (self, value : UnitSystem) -> None: ...
class File3dm:
    def __init__(self): ...
    @property
    def CreatedBy (self) -> str: ...
    @property
    def LastEditedBy (self) -> str: ...
    @property
    def Created (self) -> DateTime: ...
    @property
    def LastEdited (self) -> DateTime: ...
    @property
    def Revision (self) -> int: ...
    @Revision.setter
    def Revision (self, value : int) -> None: ...
    def GetPreviewImage (self) -> Bitmap: ...
    def SetPreviewImage (self, image : Bitmap) -> None: ...
    @property
    def Settings (self) -> File3dmSettings: ...
    @property
    def Manifest (self) -> ManifestTable: ...
    @property
    def Objects (self) -> File3dmObjectTable: ...
    @property
    def Materials (self) -> List[Material]: ...
    @property
    def AllMaterials (self) -> File3dmMaterialTable: ...
    @property
    def Linetypes (self) -> List[Linetype]: ...
    @property
    def AllLinetypes (self) -> File3dmLinetypeTable: ...
    @property
    def Layers (self) -> List[Layer]: ...
    @property
    def AllLayers (self) -> File3dmLayerTable: ...
    @property
    def AllGroups (self) -> File3dmGroupTable: ...
    @property
    def DimStyles (self) -> List[DimensionStyle]: ...
    @property
    def AllDimStyles (self) -> File3dmDimStyleTable: ...
    @property
    def HatchPatterns (self) -> List[HatchPattern]: ...
    @property
    def AllHatchPatterns (self) -> File3dmHatchPatternTable: ...
    @property
    def InstanceDefinitions (self) -> List[InstanceDefinitionGeometry]: ...
    @property
    def AllInstanceDefinitions (self) -> File3dmInstanceDefinitionTable: ...
    @property
    def Views (self) -> List[ViewInfo]: ...
    @property
    def AllViews (self) -> File3dmViewTable: ...
    @property
    def NamedViews (self) -> List[ViewInfo]: ...
    @property
    def AllNamedViews (self) -> File3dmViewTable: ...
    @property
    def NamedConstructionPlanes (self) -> List[ConstructionPlane]: ...
    @property
    def AllNamedConstructionPlanes (self) -> File3dmNamedConstructionPlanes: ...
    @property
    def PlugInData (self) -> File3dmPlugInDataTable: ...
    @property
    def Strings (self) -> File3dmStringTable: ...
    def Dump (self) -> str: ...
    def DumpSummary (self) -> str: ...
    def DumpToTextLog (self, log : TextLog) -> None: ...
    def Dispose (self) -> None: ...
    def Read (path : str) -> File3dm: ...
    def Read (path : str, tableTypeFilterFilter : TableTypeFilter, objectTypeFilter : ObjectTypeFilter) -> File3dm: ...
    def ReadWithLog (path : str, tableTypeFilterFilter : TableTypeFilter, objectTypeFilter : ObjectTypeFilter) -> Tuple[File3dm, str]: ...
    def ReadWithLog (path : str) -> Tuple[File3dm, str]: ...
    def ReadNotes (path : str) -> str: ...
    def ReadArchiveVersion (path : str) -> int: ...
    def ReadRevisionHistory (path : str) -> Tuple[bool, str, str, int, DateTime, DateTime]: ...
    def ReadApplicationData (path : str) -> Tuple[str, str, str]: ...
    def ReadPreviewImage (path : str) -> Bitmap: ...
    def ReadDimensionStyles (path : str) -> Set(DimensionStyle): ...
    def Write (self, path : str, version : int) -> bool: ...
    def Write (self, path : str, options : File3dmWriteOptions) -> bool: ...
    def WriteWithLog (self, path : str, version : int) -> Tuple[bool, str]: ...
    def WriteWithLog (self, path : str, options : File3dmWriteOptions) -> Tuple[bool, str]: ...
    def IsValid (self) -> Tuple[bool, str]: ...
    def IsValid (self, errors : TextLog) -> bool: ...
    def Polish (self) -> None: ...
    def Audit (self, attemptRepair : bool) -> Tuple[int, int, str, Set(int)]: ...
    @property
    def StartSectionComments (self) -> str: ...
    @StartSectionComments.setter
    def StartSectionComments (self, value : str) -> None: ...
    @property
    def Notes (self) -> File3dmNotes: ...
    @Notes.setter
    def Notes (self, value : File3dmNotes) -> None: ...
    @property
    def ApplicationName (self) -> str: ...
    @ApplicationName.setter
    def ApplicationName (self, value : str) -> None: ...
    @property
    def ApplicationUrl (self) -> str: ...
    @ApplicationUrl.setter
    def ApplicationUrl (self, value : str) -> None: ...
    @property
    def ApplicationDetails (self) -> str: ...
    @ApplicationDetails.setter
    def ApplicationDetails (self, value : str) -> None: ...
class File3dmWriteOptions:
    def __init__(self): ...
    @property
    def Version (self) -> int: ...
    @Version.setter
    def Version (self, value : int) -> None: ...
    @property
    def SaveRenderMeshes (self) -> bool: ...
    @SaveRenderMeshes.setter
    def SaveRenderMeshes (self, value : bool) -> None: ...
    def EnableRenderMeshes (self, objectType : ObjectType, enable : bool) -> None: ...
    @property
    def SaveAnalysisMeshes (self) -> bool: ...
    @SaveAnalysisMeshes.setter
    def SaveAnalysisMeshes (self, value : bool) -> None: ...
    def EnableAnalysisMeshes (self, objectType : ObjectType, enable : bool) -> None: ...
    @property
    def SaveUserData (self) -> bool: ...
    @SaveUserData.setter
    def SaveUserData (self, value : bool) -> None: ...
class File3dmObject(ModelComponent):
    @property
    def Geometry (self) -> GeometryBase: ...
    @property
    def Attributes (self) -> ObjectAttributes: ...
    @property
    def Name (self) -> str: ...
    @Name.setter
    def Name (self, value : str) -> None: ...
    @property
    def ComponentType (self) -> ModelComponentType: ...
    def Equals (self, obj : Object) -> bool: ...
    def Equals (self, other : File3dmObject) -> bool: ...
    def GetHashCode (self) -> int: ...
class ManifestTable:
    @property
    def Parent (self) -> Object: ...
    def FindId (self, id : Guid) -> ModelComponent: ...
    def FindId (self, id : Guid, type : ModelComponentType) -> ModelComponent: ...
    def FindId (self, id : Guid) -> T: ...
    def FindIndex (self, index : int, type : ModelComponentType) -> ModelComponent: ...
    def FindIndex (self, index : int) -> T: ...
    def FindName (self, name : str, type : ModelComponentType, parent : Guid) -> ModelComponent: ...
    def FindName (self, name : str, parent : Guid) -> T: ...
    def FindNameHash (self, nameHash : NameHash, type : ModelComponentType) -> ModelComponent: ...
    def FindNameHash (self, nameHash : NameHash) -> T: ...
    @property
    def Count (self) -> int: ...
    @property
    def LongCount (self) -> Int64: ...
    @property
    def ComponentType (self) -> ModelComponentType: ...
    def ActiveObjectCount (self, type : ModelComponentType) -> int: ...
    def GetEnumerator (self) -> IEnumerator: ...
    def GetModelComponentTypeFromGenericType () -> ModelComponentType: ...
    def GetEnumerator (self) -> IEnumerator: ...
    def GetEnumerator (self, type : ModelComponentType) -> IEnumerator: ...
    def Clear (self) -> None: ...
    def Contains (self, item : ModelComponent) -> bool: ...
    def CopyTo (self, array : Set(ModelComponent), arrayIndex : int) -> None: ...
class File3dmObjectTable:
    @property
    def ComponentType (self) -> ModelComponentType: ...
    def FindByLayer (self, layer : str) -> Set(File3dmObject): ...
    def FindByLayer (self, layer : Layer) -> Set(File3dmObject): ...
    def GetBoundingBox (self) -> BoundingBox: ...
    def Add (self, item : File3dmObject) -> None: ...
    def AddPoint (self, x : float, y : float, z : float) -> Guid: ...
    def AddPoint (self, point : Point3d) -> Guid: ...
    def AddPoint (self, point : Point3d, attributes : ObjectAttributes) -> Guid: ...
    def AddPoint (self, point : Point3f) -> Guid: ...
    def AddPoint (self, point : Point3f, attributes : ObjectAttributes) -> Guid: ...
    def AddPoints (self, points : Iterable[Point3d]) -> Set(Guid): ...
    def AddPoints (self, points : Iterable[Point3d], attributes : ObjectAttributes) -> Set(Guid): ...
    def AddPoints (self, points : Iterable[Point3f]) -> Set(Guid): ...
    def AddPoints (self, points : Iterable[Point3f], attributes : ObjectAttributes) -> Set(Guid): ...
    def AddPointCloud (self, cloud : PointCloud) -> Guid: ...
    def AddPointCloud (self, cloud : PointCloud, attributes : ObjectAttributes) -> Guid: ...
    def AddPointCloud (self, points : Iterable[Point3d]) -> Guid: ...
    def AddPointCloud (self, points : Iterable[Point3d], attributes : ObjectAttributes) -> Guid: ...
    def AddClippingPlane (self, plane : Plane, uMagnitude : float, vMagnitude : float, clippedViewportId : Guid) -> Guid: ...
    def AddClippingPlane (self, plane : Plane, uMagnitude : float, vMagnitude : float, clippedViewportIds : Iterable[Guid]) -> Guid: ...
    def AddClippingPlane (self, plane : Plane, uMagnitude : float, vMagnitude : float, clippedViewportIds : Iterable[Guid], attributes : ObjectAttributes) -> Guid: ...
    def AddLinearDimension (self, dimension : LinearDimension) -> Guid: ...
    def AddLinearDimension (self, dimension : LinearDimension, attributes : ObjectAttributes) -> Guid: ...
    def AddAngularDimension (self, dimension : AngularDimension) -> Guid: ...
    def AddAngularDimension (self, dimension : AngularDimension, attributes : ObjectAttributes) -> Guid: ...
    def AddLine (self, from_ : Point3d, to : Point3d) -> Guid: ...
    def AddLine (self, from_ : Point3d, to : Point3d, attributes : ObjectAttributes) -> Guid: ...
    def AddLine (self, line : Line) -> Guid: ...
    def AddLine (self, line : Line, attributes : ObjectAttributes) -> Guid: ...
    def AddPolyline (self, points : Iterable[Point3d]) -> Guid: ...
    def AddPolyline (self, points : Iterable[Point3d], attributes : ObjectAttributes) -> Guid: ...
    def AddArc (self, arc : Arc) -> Guid: ...
    def AddArc (self, arc : Arc, attributes : ObjectAttributes) -> Guid: ...
    def AddCircle (self, circle : Circle) -> Guid: ...
    def AddCircle (self, circle : Circle, attributes : ObjectAttributes) -> Guid: ...
    def AddEllipse (self, ellipse : Ellipse) -> Guid: ...
    def AddEllipse (self, ellipse : Ellipse, attributes : ObjectAttributes) -> Guid: ...
    def AddSphere (self, sphere : Sphere) -> Guid: ...
    def AddSphere (self, sphere : Sphere, attributes : ObjectAttributes) -> Guid: ...
    def AddCurve (self, curve : Curve) -> Guid: ...
    def AddCurve (self, curve : Curve, attributes : ObjectAttributes) -> Guid: ...
    def AddTextDot (self, text : str, location : Point3d) -> Guid: ...
    def AddTextDot (self, text : str, location : Point3d, attributes : ObjectAttributes) -> Guid: ...
    def AddTextDot (self, dot : TextDot) -> Guid: ...
    def AddTextDot (self, dot : TextDot, attributes : ObjectAttributes) -> Guid: ...
    def AddInstanceObject (self, instanceReference : InstanceReferenceGeometry) -> Guid: ...
    def AddInstanceObject (self, instanceReference : InstanceReferenceGeometry, attributes : ObjectAttributes) -> Guid: ...
    def AddInstanceObject (self, instanceDefinitionIndex : int, instanceXform : Transform) -> Guid: ...
    def AddInstanceObject (self, instanceDefinitionIndex : int, instanceXform : Transform, attributes : ObjectAttributes) -> Guid: ...
    def AddText (self, text3d : Text3d) -> Guid: ...
    def AddText (self, text3d : Text3d, attributes : ObjectAttributes) -> Guid: ...
    def AddText (self, text : str, plane : Plane, height : float, fontName : str, bold : bool, italic : bool) -> Guid: ...
    def AddText (self, text : str, plane : Plane, height : float, fontName : str, bold : bool, italic : bool, justification : TextJustification) -> Guid: ...
    def AddText (self, text : str, plane : Plane, height : float, fontName : str, bold : bool, italic : bool, justification : TextJustification, attributes : ObjectAttributes) -> Guid: ...
    def AddText (self, text : str, plane : Plane, height : float, fontName : str, bold : bool, italic : bool, attributes : ObjectAttributes) -> Guid: ...
    def AddSurface (self, surface : Surface) -> Guid: ...
    def AddSurface (self, surface : Surface, attributes : ObjectAttributes) -> Guid: ...
    def AddExtrusion (self, extrusion : Extrusion) -> Guid: ...
    def AddExtrusion (self, extrusion : Extrusion, attributes : ObjectAttributes) -> Guid: ...
    def AddMesh (self, mesh : Mesh) -> Guid: ...
    def AddMesh (self, mesh : Mesh, attributes : ObjectAttributes) -> Guid: ...
    def AddBrep (self, brep : Brep) -> Guid: ...
    def AddBrep (self, brep : Brep, attributes : ObjectAttributes) -> Guid: ...
    def AddLeader (self, plane : Plane, points : Iterable[Point2d]) -> Guid: ...
    def AddLeader (self, plane : Plane, points : Iterable[Point2d], attributes : ObjectAttributes) -> Guid: ...
    def AddLeader (self, text : str, plane : Plane, points : Iterable[Point2d], attributes : ObjectAttributes) -> Guid: ...
    def AddLeader (self, text : str, plane : Plane, points : Iterable[Point2d]) -> Guid: ...
    def AddLeader (self, text : str, points : Iterable[Point3d]) -> Guid: ...
    def AddLeader (self, points : Iterable[Point3d]) -> Guid: ...
    def AddHatch (self, hatch : Hatch) -> Guid: ...
    def AddHatch (self, hatch : Hatch, attributes : ObjectAttributes) -> Guid: ...
    def Delete (self, objectId : Guid) -> bool: ...
    def Delete (self, objectIds : Iterable[Guid]) -> int: ...
    @property
    def Count (self) -> int: ...
    def GetEnumerator (self) -> IEnumerator: ...
class File3dmPlugInData:
    @property
    def PlugInId (self) -> Guid: ...
class File3dmPlugInDataTable:
    def Dump (self) -> str: ...
    @property
    def Count (self) -> int: ...
    @property
    def Item (self, index : int) -> File3dmPlugInData: ...
    def Clear (self) -> None: ...
    def GetEnumerator (self) -> IEnumerator: ...
class File3dmMaterialTable:
    @property
    def ComponentType (self) -> ModelComponentType: ...
    def FindIndex (self, index : int) -> Material: ...
class File3dmLinetypeTable:
    @property
    def ComponentType (self) -> ModelComponentType: ...
    def FindName (self, name : str) -> Linetype: ...
    def FindNameHash (self, nameHash : NameHash) -> Linetype: ...
    def FindIndex (self, index : int) -> Linetype: ...
class File3dmLayerTable:
    @property
    def ComponentType (self) -> ModelComponentType: ...
    def FindName (self, name : str, parentId : Guid) -> Layer: ...
    def FindNameHash (self, nameHash : NameHash) -> Layer: ...
    def FindIndex (self, index : int) -> Layer: ...
class File3dmGroupTable:
    @property
    def ComponentType (self) -> ModelComponentType: ...
    def FindName (self, name : str) -> Group: ...
    def FindNameHash (self, nameHash : NameHash) -> Group: ...
    def FindIndex (self, index : int) -> Group: ...
class File3dmDimStyleTable:
    @property
    def ComponentType (self) -> ModelComponentType: ...
    def FindName (self, name : str) -> DimensionStyle: ...
    def FindNameHash (self, nameHash : NameHash) -> DimensionStyle: ...
    def FindIndex (self, index : int) -> DimensionStyle: ...
class File3dmHatchPatternTable:
    @property
    def ComponentType (self) -> ModelComponentType: ...
    def FindName (self, name : str) -> HatchPattern: ...
    def FindNameHash (self, nameHash : NameHash) -> HatchPattern: ...
    def FindIndex (self, index : int) -> HatchPattern: ...
class File3dmInstanceDefinitionTable:
    @property
    def ComponentType (self) -> ModelComponentType: ...
    def FindName (self, name : str) -> InstanceDefinitionGeometry: ...
    def FindNameHash (self, nameHash : NameHash) -> InstanceDefinitionGeometry: ...
    def Add (self, name : str, description : str, basePoint : Point3d, geometry : Iterable[GeometryBase], attributes : Iterable[ObjectAttributes]) -> int: ...
    def Add (self, name : str, description : str, basePoint : Point3d, geometry : Iterable[GeometryBase]) -> int: ...
    def Add (self, name : str, description : str, basePoint : Point3d, geometry : GeometryBase, attributes : ObjectAttributes) -> int: ...
    def AddLinked (self, filename : str, name : str, description : str) -> int: ...
class File3dmViewTable:
    def FindName (self, name : str) -> ViewInfo: ...
    def IndexOf (self, item : ViewInfo) -> int: ...
    def Delete (self, index : int) -> bool: ...
    @property
    def Item (self, index : int) -> ViewInfo: ...
    def Add (self, item : ViewInfo) -> None: ...
    def Clear (self) -> None: ...
    def Contains (self, item : ViewInfo) -> bool: ...
    def CopyTo (self, array : Set(ViewInfo), arrayIndex : int) -> None: ...
    @property
    def Count (self) -> int: ...
    def Delete (self, item : ViewInfo) -> bool: ...
    def GetEnumerator (self) -> IEnumerator: ...
class File3dmNamedConstructionPlanes:
    def FindName (self, name : str) -> ConstructionPlane: ...
    def IndexOf (self, cplane : ConstructionPlane) -> int: ...
    def Delete (self, index : int) -> bool: ...
    def Delete (self, cplane : ConstructionPlane) -> bool: ...
    @property
    def Item (self, index : int) -> ConstructionPlane: ...
    def Add (self, name : str, plane : Plane) -> int: ...
    def Add (self, cplane : ConstructionPlane) -> None: ...
    def Clear (self) -> None: ...
    def Contains (self, cplane : ConstructionPlane) -> bool: ...
    def CopyTo (self, array : Set(ConstructionPlane), arrayIndex : int) -> None: ...
    @property
    def Count (self) -> int: ...
    def GetEnumerator (self) -> IEnumerator: ...
class File3dmStringTable:
    @property
    def Count (self) -> int: ...
    @property
    def DocumentUserTextCount (self) -> int: ...
    def GetKey (self, i : int) -> str: ...
    def GetValue (self, i : int) -> str: ...
    def GetValue (self, key : str) -> str: ...
    def GetValue (self, section : str, entry : str) -> str: ...
    def GetSectionNames (self) -> Set(str): ...
    def GetEntryNames (self, section : str) -> Set(str): ...
    def SetString (self, section : str, entry : str, value : str) -> str: ...
    def SetString (self, key : str, value : str) -> str: ...
    def Delete (self, section : str, entry : str) -> None: ...
    def Delete (self, key : str) -> None: ...
class FileReference:
    def __init__(self, fullPath : str, relativePath : str, hash : ContentHash, status : FileReferenceStatus): ...
    def CreateFromFullPath (fullPath : str) -> FileReference: ...
    def CreateFromFullAndRelativePaths (fullPath : str, relativePath : str) -> FileReference: ...
    @property
    def FullPath (self) -> str: ...
    @property
    def RelativePath (self) -> str: ...
    @property
    def ContentHash (self) -> ContentHash: ...
    @property
    def FullPathStatus (self) -> FileReferenceStatus: ...
    @property
    def IsSet (self) -> bool: ...
    def Dispose (self) -> None: ...
class NameHash:
    def __init__(self, name : str): ...
    def __init__(self, name : str, parentId : Guid): ...
    def __init__(self, name : str, parentId : Guid, type : ModelComponentType): ...
    def __init__(self, name : str, parentId : Guid, ignoreCase : bool): ...
    @property
    def Sha1Hash (self) -> Set(Byte): ...
    @property
    def MappedCodePoints (self) -> UInt32: ...
    @property
    def ParentId (self) -> Guid: ...
    def CreateFilePathHash (path : str) -> NameHash: ...
    def Clone (self) -> NameHash: ...
    def Equals (self, other : NameHash) -> bool: ...
    def Equals (self, obj : Object) -> bool: ...
    def GetHashCode (self) -> int: ...
    def op_Equality (left : NameHash, right : NameHash) -> bool: ...
    def op_Inequality (left : NameHash, right : NameHash) -> bool: ...
class ContentHash:
    @property
    def Sha1NameHash (self) -> Set(Byte): ...
    @property
    def ByteCount (self) -> UInt64: ...
    @property
    def Sha1ContentHash (self) -> Set(Byte): ...
    @property
    def HashTime (self) -> DateTime: ...
    def CreateFromFile (path : str) -> ContentHash: ...
    def Clone (self) -> ContentHash: ...
    def Equals (self, other : ContentHash) -> bool: ...
    def Equals (self, obj : Object) -> bool: ...
    def GetHashCode (self) -> int: ...
    def op_Equality (left : ContentHash, right : ContentHash) -> bool: ...
    def op_Inequality (left : ContentHash, right : ContentHash) -> bool: ...
class SHA1OpenNURBS:
    def __init__(self): ...
    def Initialize (self) -> None: ...
    def StringHash (input : str) -> Set(Byte): ...
    def FileSystemPathHash (path : str, ignoreCase : Nullable) -> Set(Byte): ...
class TextLog:
    def __init__(self): ...
    def __init__(self, filename : str): ...
    def __init__(self, ptr : IntPtr): ...
    def ToString (self) -> str: ...
    def PushIndent (self) -> None: ...
    def PopIndent (self) -> None: ...
    @property
    def IndentSize (self) -> int: ...
    @IndentSize.setter
    def IndentSize (self, value : int) -> None: ...
    def PrintWrappedText (self, text : str, lineLength : int) -> None: ...
    def Print (self, text : str) -> None: ...
    def Print (self, format : str, arg0 : Object) -> None: ...
    def Print (self, format : str, arg0 : Object, arg1 : Object) -> None: ...
    def Dispose (self) -> None: ...
class File3dmTypeCodes:
class FileWriteOptions:
    def __init__(self): ...
    @property
    def UpdateDocumentPath (self) -> bool: ...
    @UpdateDocumentPath.setter
    def UpdateDocumentPath (self, value : bool) -> None: ...
    @property
    def WriteSelectedObjectsOnly (self) -> bool: ...
    @WriteSelectedObjectsOnly.setter
    def WriteSelectedObjectsOnly (self, value : bool) -> None: ...
    @property
    def IncludeRenderMeshes (self) -> bool: ...
    @IncludeRenderMeshes.setter
    def IncludeRenderMeshes (self, value : bool) -> None: ...
    @property
    def IncludePreviewImage (self) -> bool: ...
    @IncludePreviewImage.setter
    def IncludePreviewImage (self, value : bool) -> None: ...
    @property
    def IncludeBitmapTable (self) -> bool: ...
    @IncludeBitmapTable.setter
    def IncludeBitmapTable (self, value : bool) -> None: ...
    @property
    def IncludeHistory (self) -> bool: ...
    @IncludeHistory.setter
    def IncludeHistory (self, value : bool) -> None: ...
    @property
    def WriteAsTemplate (self) -> bool: ...
    @property
    def SuppressDialogBoxes (self) -> bool: ...
    @SuppressDialogBoxes.setter
    def SuppressDialogBoxes (self, value : bool) -> None: ...
    @property
    def SuppressAllInput (self) -> bool: ...
    @SuppressAllInput.setter
    def SuppressAllInput (self, value : bool) -> None: ...
    @property
    def WriteGeometryOnly (self) -> bool: ...
    @WriteGeometryOnly.setter
    def WriteGeometryOnly (self, value : bool) -> None: ...
    @property
    def WriteUserData (self) -> bool: ...
    @WriteUserData.setter
    def WriteUserData (self, value : bool) -> None: ...
    @property
    def FileVersion (self) -> int: ...
    @FileVersion.setter
    def FileVersion (self, value : int) -> None: ...
    @property
    def Xform (self) -> Transform: ...
    @Xform.setter
    def Xform (self, value : Transform) -> None: ...
    @property
    def DestinationFileName (self) -> str: ...
    def Dispose (self) -> None: ...
class FileReadOptions:
    def __init__(self): ...
    @property
    def ImportMode (self) -> bool: ...
    @ImportMode.setter
    def ImportMode (self, value : bool) -> None: ...
    @property
    def OpenMode (self) -> bool: ...
    @OpenMode.setter
    def OpenMode (self, value : bool) -> None: ...
    @property
    def NewMode (self) -> bool: ...
    @NewMode.setter
    def NewMode (self, value : bool) -> None: ...
    @property
    def InsertMode (self) -> bool: ...
    @InsertMode.setter
    def InsertMode (self, value : bool) -> None: ...
    @property
    def ImportReferenceMode (self) -> bool: ...
    @ImportReferenceMode.setter
    def ImportReferenceMode (self, value : bool) -> None: ...
    @property
    def BatchMode (self) -> bool: ...
    @BatchMode.setter
    def BatchMode (self, value : bool) -> None: ...
    @property
    def UseScaleGeometry (self) -> bool: ...
    @UseScaleGeometry.setter
    def UseScaleGeometry (self, value : bool) -> None: ...
    @property
    def ScaleGeometry (self) -> bool: ...
    @ScaleGeometry.setter
    def ScaleGeometry (self, value : bool) -> None: ...
    def Dispose (self) -> None: ...
class FileType:
    def __init__(self, extension : str, description : str): ...
    @property
    def Description (self) -> str: ...
    @property
    def Extension (self) -> str: ...
class File3dmNotes:
    def __init__(self): ...
    @property
    def Notes (self) -> str: ...
    @Notes.setter
    def Notes (self, value : str) -> None: ...
    @property
    def IsVisible (self) -> bool: ...
    @IsVisible.setter
    def IsVisible (self, value : bool) -> None: ...
    @property
    def IsHtml (self) -> bool: ...
    @IsHtml.setter
    def IsHtml (self, value : bool) -> None: ...
    @property
    def WindowRectangle (self) -> Rectangle: ...
    @WindowRectangle.setter
    def WindowRectangle (self, value : Rectangle) -> None: ...
class BinaryArchiveException:
    def __init__(self, message : str): ...
class BinaryArchiveWriter:
    @property
    def WriteErrorOccured (self) -> bool: ...
    @WriteErrorOccured.setter
    def WriteErrorOccured (self, value : bool) -> None: ...
    @property
    def Archive3dmVersion (self) -> int: ...
    def BeginWrite3dmChunk (self, typecode : UInt32, majorVersion : int, minorVersion : int) -> bool: ...
    def BeginWrite3dmChunk (self, typecode : UInt32, value : Int64) -> bool: ...
    def EndWrite3dmChunk (self) -> bool: ...
    def EnableCRCCalculation (self, enable : bool) -> bool: ...
    def Write3dmChunkVersion (self, major : int, minor : int) -> None: ...
    def WriteDictionary (self, dictionary : ArchivableDictionary) -> None: ...
    def WriteBool (self, value : bool) -> None: ...
    def WriteByte (self, value : Byte) -> None: ...
    def WriteSByte (self, value : SByte) -> None: ...
    def WriteShort (self, value : Int16) -> None: ...
    def WriteUShort (self, value : UInt16) -> None: ...
    def WriteInt (self, value : int) -> None: ...
    def WriteUInt (self, value : UInt32) -> None: ...
    def WriteInt64 (self, value : Int64) -> None: ...
    def WriteSingle (self, value : Single) -> None: ...
    def WriteDouble (self, value : float) -> None: ...
    def WriteGuid (self, value : Guid) -> None: ...
    def WriteString (self, value : str) -> None: ...
    def WriteUtf8String (self, value : str) -> None: ...
    def WriteBoolArray (self, value : Iterable[bool]) -> None: ...
    def WriteByteArray (self, value : Iterable[Byte]) -> None: ...
    def WriteCompressedBuffer (self, value : Iterable[Byte]) -> None: ...
    def WriteSByteArray (self, value : Iterable[SByte]) -> None: ...
    def WriteShortArray (self, value : Iterable[Int16]) -> None: ...
    def WriteIntArray (self, value : Iterable[int]) -> None: ...
    def WriteSingleArray (self, value : Iterable[Single]) -> None: ...
    def WriteDoubleArray (self, value : Iterable[float]) -> None: ...
    def WriteGuidArray (self, value : Iterable[Guid]) -> None: ...
    def WriteStringArray (self, value : Iterable[str]) -> None: ...
    def WriteColor (self, value : Color) -> None: ...
    def WritePoint (self, value : Point) -> None: ...
    def WritePointF (self, value : PointF) -> None: ...
    def WriteRectangle (self, value : Rectangle) -> None: ...
    def WriteRectangleF (self, value : RectangleF) -> None: ...
    def WriteSize (self, value : Size) -> None: ...
    def WriteSizeF (self, value : SizeF) -> None: ...
    def WriteFont (self, value : Font) -> None: ...
    def WriteObjRef (self, objref : ObjRef) -> None: ...
    def WriteObjRefArray (self, objrefs : Iterable[ObjRef]) -> None: ...
    def WriteGeometryArray (self, geometry : Iterable[GeometryBase]) -> None: ...
    def WriteInterval (self, value : Interval) -> None: ...
    def WritePoint2d (self, value : Point2d) -> None: ...
    def WritePoint3d (self, value : Point3d) -> None: ...
    def WritePoint4d (self, value : Point4d) -> None: ...
    def WriteVector2d (self, value : Vector2d) -> None: ...
    def WriteVector3d (self, value : Vector3d) -> None: ...
    def WriteBoundingBox (self, value : BoundingBox) -> None: ...
    def WriteRay3d (self, value : Ray3d) -> None: ...
    def WriteTransform (self, value : Transform) -> None: ...
    def WritePlane (self, value : Plane) -> None: ...
    def WriteLine (self, value : Line) -> None: ...
    def WritePoint3f (self, value : Point3f) -> None: ...
    def WriteVector3f (self, value : Vector3f) -> None: ...
    def WriteMeshingParameters (self, value : MeshingParameters) -> None: ...
    def WriteGeometry (self, value : GeometryBase) -> None: ...
    def WriteRenderSettings (self, value : RenderSettings) -> None: ...
    def WriteEmptyCheckSum (self) -> None: ...
class BinaryArchiveReader:
    @property
    def ReadErrorOccured (self) -> bool: ...
    @ReadErrorOccured.setter
    def ReadErrorOccured (self, value : bool) -> None: ...
    @property
    def Archive3dmVersion (self) -> int: ...
    def EnableCRCCalculation (self, enable : bool) -> bool: ...
    @property
    def CurrentPosition (self) -> UInt64: ...
    def SeekFromCurrentPosition (self, byteOffset : Int64) -> bool: ...
    def SeekFromCurrentPosition (self, byteOffset : UInt64, forward : bool) -> bool: ...
    def SeekFromStart (self, byteOffset : UInt64) -> bool: ...
    def BeginRead3dmChunk (self, expectedTypeCode : UInt32) -> Tuple[bool, int, int]: ...
    def BeginRead3dmChunk (self) -> Tuple[bool, UInt32, Int64]: ...
    def EndRead3dmChunk (self, suppressPartiallyReadChunkWarning : bool) -> bool: ...
    def Read3dmChunkVersion (self) -> Tuple[int, int]: ...
    def ReadDictionary (self) -> ArchivableDictionary: ...
    def ReadBool (self) -> bool: ...
    def ReadByte (self) -> Byte: ...
    def ReadSByte (self) -> SByte: ...
    def ReadShort (self) -> Int16: ...
    def ReadUShort (self) -> UInt16: ...
    def ReadInt (self) -> int: ...
    def ReadUInt (self) -> UInt32: ...
    def ReadInt64 (self) -> Int64: ...
    def ReadSingle (self) -> Single: ...
    def ReadDouble (self) -> float: ...
    def ReadGuid (self) -> Guid: ...
    def ReadString (self) -> str: ...
    def ReadUtf8String (self) -> str: ...
    def ReadBoolArray (self) -> Set(bool): ...
    def ReadByteArray (self) -> Set(Byte): ...
    def ReadCompressedBuffer (self) -> Set(Byte): ...
    def ReadSByteArray (self) -> Set(SByte): ...
    def ReadShortArray (self) -> Set(Int16): ...
    def ReadIntArray (self) -> Set(int): ...
    def ReadSingleArray (self) -> Set(Single): ...
    def ReadDoubleArray (self) -> Set(float): ...
    def ReadGuidArray (self) -> Set(Guid): ...
    def ReadStringArray (self) -> Set(str): ...
    def ReadColor (self) -> Color: ...
    def ReadPoint (self) -> Point: ...
    def ReadPointF (self) -> PointF: ...
    def ReadRectangle (self) -> Rectangle: ...
    def ReadRectangleF (self) -> RectangleF: ...
    def ReadSize (self) -> Size: ...
    def ReadSizeF (self) -> SizeF: ...
    def ReadFont (self) -> Font: ...
    def ReadObjRef (self) -> ObjRef: ...
    def ReadObjRefArray (self) -> Set(ObjRef): ...
    def ReadInterval (self) -> Interval: ...
    def ReadPoint2d (self) -> Point2d: ...
    def ReadPoint3d (self) -> Point3d: ...
    def ReadPoint4d (self) -> Point4d: ...
    def ReadVector2d (self) -> Vector2d: ...
    def ReadVector3d (self) -> Vector3d: ...
    def ReadBoundingBox (self) -> BoundingBox: ...
    def ReadRay3d (self) -> Ray3d: ...
    def ReadTransform (self) -> Transform: ...
    def ReadPlane (self) -> Plane: ...
    def ReadLine (self) -> Line: ...
    def ReadPoint3f (self) -> Point3f: ...
    def ReadVector3f (self) -> Vector3f: ...
    def ReadMeshingParameters (self) -> MeshingParameters: ...
    def ReadGeometry (self) -> GeometryBase: ...
    def ReadGeometryArray (self) -> Set(GeometryBase): ...
    def ReadRenderSettings (self) -> RenderSettings: ...
    def ReadCheckSum (self) -> None: ...
    def Read3dmStartSection (self) -> Tuple[bool, int, str]: ...
    def Dump3dmChunk (self, log : TextLog) -> UInt32: ...
    def AtEnd (self) -> bool: ...
class BinaryArchiveMode:
    Unknown = 0
    Read = 1
    Write = 2
    ReadWrite = 3
    Read3dm = 5
    Write3dm = 6
class BinaryArchiveFile:
    def __init__(self, filename : str, mode : BinaryArchiveMode): ...
    def Open (self) -> bool: ...
    def Close (self) -> None: ...
    @property
    def Reader (self) -> BinaryArchiveReader: ...
    @property
    def Writer (self) -> BinaryArchiveWriter: ...
    def Dispose (self) -> None: ...
class SerializationOptions:
    def __init__(self): ...
    @property
    def RhinoVersion (self) -> int: ...
    @RhinoVersion.setter
    def RhinoVersion (self, value : int) -> None: ...
    @property
    def WriteUserData (self) -> bool: ...
    @WriteUserData.setter
    def WriteUserData (self, value : bool) -> None: ...
class AsciiEol:
    Crlf = 0
    Lf = 1
    Cr = 2
class CurveType:
    Polyline = 0
    Nurbs = 1
class GeometryType:
    Nurbs = 0
    Mesh = 1
class ObjObjectNames:
    NoObjects = 0
    ObjectAsGroup = 1
    ObjectAsObject = 2
class ObjGroupNames:
    NoGroups = 0
    LayerAsGroup = 1
    GroupAsGroup = 2
class VertexWelding:
    Normal = 0
    Welded = 1
    Unwelded = 2
class SubDMeshing:
    Surface = 0
    ControlNet = 1
class UseObjGsAs:
    IgnoreObjGroups = 0
    ObjGroupsAsLayers = 1
    ObjGroupsAsGroups = 2
    ObjGroupsAsObjects = 3
class TableTypeFilter:
    None = 0
    Properties = 1
    Settings = 2
    Bitmap = 4
    TextureMapping = 8
    Material = 16
    Linetype = 32
    Layer = 64
    Group = 128
    Font = 256
    FutureFont = 512
    Dimstyle = 1024
    Light = 2048
    Hatchpattern = 4096
    InstanceDefinition = 8192
    ObjectTable = 16384
    Historyrecord = 32768
    UserTable = 65536
class ObjectTypeFilter:
    None = 0
    Point = 1
    Pointset = 2
    Curve = 4
    Surface = 8
    Brep = 16
    Mesh = 32
    Annotation = 512
    InstanceDefinition = 2048
    InstanceReference = 4096
    TextDot = 8192
    DetailView = 32768
    Hatch = 65536
    Extrusion = 1073741824
    Any = 4294967295
