from typing import Tuple, Set, Iterable, List

class BrepVertexList:
    @property
    def Count (self) -> int: ...
    @property
    def Item (self, index : int) -> BrepVertex: ...
    def Add (self) -> BrepVertex: ...
    def Add (self, point : Point3d, vertexTolerance : float) -> BrepVertex: ...
    def AddPointOnFace (self, face : BrepFace, s : float, t : float) -> BrepVertex: ...
    def GetEnumerator (self) -> IEnumerator: ...
class BrepFaceList:
    @property
    def Count (self) -> int: ...
    @property
    def Item (self, index : int) -> BrepFace: ...
    def ShrinkFaces (self) -> bool: ...
    def SplitKinkyFaces (self) -> bool: ...
    def SplitKinkyFaces (self, kinkTolerance : float) -> bool: ...
    def SplitKinkyFaces (self, kinkTolerance : float, compact : bool) -> bool: ...
    def SplitKinkyFace (self, faceIndex : int, kinkTolerance : float) -> bool: ...
    def SplitClosedFaces (self, minimumDegree : int) -> bool: ...
    def SplitBipolarFaces (self) -> bool: ...
    def SplitFacesAtTangents (self) -> bool: ...
    def SplitFaceAtTangents (self, faceIndex : int) -> bool: ...
    def Flip (self, onlyReversedFaces : bool) -> None: ...
    def RemoveAt (self, faceIndex : int) -> None: ...
    def ExtractFace (self, faceIndex : int) -> Brep: ...
    def StandardizeFaceSurface (self, faceIndex : int) -> bool: ...
    def StandardizeFaceSurfaces (self) -> None: ...
    def Add (self, surfaceIndex : int) -> BrepFace: ...
    def Add (self, surface : Surface) -> BrepFace: ...
    def AddRuledFace (self, edgeA : BrepEdge, revEdgeA : bool, edgeB : BrepEdge, revEdgeB : bool) -> BrepFace: ...
    def AddConeFace (self, vertex : BrepVertex, edge : BrepEdge, revEdge : bool) -> BrepFace: ...
    def RemoveSlits (self) -> bool: ...
    def GetEnumerator (self) -> IEnumerator: ...
class BrepSurfaceList:
    @property
    def Count (self) -> int: ...
    @property
    def Item (self, index : int) -> Surface: ...
    def GetEnumerator (self) -> IEnumerator: ...
class BrepCurveList:
    @property
    def Count (self) -> int: ...
    @property
    def Item (self, index : int) -> Curve: ...
    def Add (self, curve : Curve) -> int: ...
    def GetEnumerator (self) -> IEnumerator: ...
class BrepEdgeList:
    @property
    def Count (self) -> int: ...
    @property
    def Item (self, index : int) -> BrepEdge: ...
    def SplitKinkyEdge (self, edgeIndex : int, kinkToleranceRadians : float) -> bool: ...
    def SplitEdgeAtParameters (self, edgeIndex : int, edgeParameters : Iterable[float]) -> int: ...
    def Add (self, curve3dIndex : int) -> BrepEdge: ...
    def Add (self, startVertex : BrepVertex, endVertex : BrepVertex, curve3dIndex : int, subDomain : Interval, edgeTolerance : float) -> BrepEdge: ...
    def Add (self, startVertex : BrepVertex, endVertex : BrepVertex, curve3dIndex : int, edgeTolerance : float) -> BrepEdge: ...
    def Add (self, startVertexIndex : int, endVertexIndex : int, curve3dIndex : int, subDomain : Interval, edgeTolerance : float) -> BrepEdge: ...
    def Add (self, startVertexIndex : int, endVertexIndex : int, curve3dIndex : int, edgeTolerance : float) -> BrepEdge: ...
    def GetEnumerator (self) -> IEnumerator: ...
class BrepTrimList:
    @property
    def Count (self) -> int: ...
    @property
    def Item (self, index : int) -> BrepTrim: ...
    def Add (self, curve2dIndex : int) -> BrepTrim: ...
    def Add (self, rev3d : bool, loop : BrepLoop, curve2dIndex : int) -> BrepTrim: ...
    def Add (self, rev3d : bool, edge : BrepEdge, curve2dIndex : int) -> BrepTrim: ...
    def Add (self, edge : BrepEdge, rev3d : bool, loop : BrepLoop, curve2dIndex : int) -> BrepTrim: ...
    def AddSingularTrim (self, vertex : BrepVertex, loop : BrepLoop, iso : IsoStatus, curve2dIndex : int) -> BrepTrim: ...
    def AddCurveOnFace (self, face : BrepFace, edge : BrepEdge, rev3d : bool, curve2dIndex : int) -> BrepTrim: ...
    def GetEnumerator (self) -> IEnumerator: ...
class BrepLoopList:
    @property
    def Count (self) -> int: ...
    @property
    def Item (self, index : int) -> BrepLoop: ...
    def Add (self, loopType : BrepLoopType) -> BrepLoop: ...
    def Add (self, loopType : BrepLoopType, face : BrepFace) -> BrepLoop: ...
    def AddOuterLoop (self, faceIndex : int) -> BrepLoop: ...
    def AddPlanarFaceLoop (self, faceIndex : int, loopType : BrepLoopType, boundaryCurves : Iterable[Curve]) -> BrepLoop: ...
    def GetEnumerator (self) -> IEnumerator: ...
class MeshVertexList:
    @property
    def Count (self) -> int: ...
    @Count.setter
    def Count (self, value : int) -> None: ...
    @property
    def Capacity (self) -> int: ...
    @Capacity.setter
    def Capacity (self, value : int) -> None: ...
    @property
    def Item (self, index : int) -> Point3f: ...
    @Item.setter
    def Item (self, index : int, value : Point3f) -> None: ...
    @property
    def UseDoublePrecisionVertices (self) -> bool: ...
    @UseDoublePrecisionVertices.setter
    def UseDoublePrecisionVertices (self, value : bool) -> None: ...
    def Clear (self) -> None: ...
    def Destroy (self) -> None: ...
    def Add (self, x : Single, y : Single, z : Single) -> int: ...
    def Add (self, x : float, y : float, z : float) -> int: ...
    def Add (self, vertex : Point3f) -> int: ...
    def Add (self, vertex : Point3d) -> int: ...
    def AddVertices (self, vertices : Iterable[Point3d]) -> None: ...
    def AddVertices (self, vertices : Iterable[Point3f]) -> None: ...
    def SetVertex (self, index : int, x : Single, y : Single, z : Single) -> bool: ...
    def SetVertex (self, index : int, x : float, y : float, z : float, updateNormals : bool) -> bool: ...
    def SetVertex (self, index : int, x : float, y : float, z : float) -> bool: ...
    def SetVertex (self, index : int, vertex : Point3f) -> bool: ...
    def SetVertex (self, index : int, vertex : Point3d) -> bool: ...
    def IsHidden (self, vertexIndex : int) -> bool: ...
    def Hide (self, vertexIndex : int) -> None: ...
    def Show (self, vertexIndex : int) -> None: ...
    def HideAll (self) -> None: ...
    def ShowAll (self) -> None: ...
    def CullUnused (self) -> int: ...
    def CombineIdentical (self, ignoreNormals : bool, ignoreAdditional : bool) -> bool: ...
    def Align (self, distance : float, whichVertices : Iterable[bool]) -> int: ...
    def Align (meshes : Iterable[Mesh], distance : float, whichVertices : Iterable[Iterable[bool]]) -> int: ...
    def GetVertexFaces (self, vertexIndex : int) -> Set(int): ...
    def GetTopologicalIndenticalVertices (self, vertexIndex : int) -> Set(int): ...
    def GetConnectedVertices (self, vertexIndex : int) -> Set(int): ...
    def Point3dAt (self, index : int) -> Point3d: ...
    def ToPoint3fArray (self) -> Set(Point3f): ...
    def ToPoint3dArray (self) -> Set(Point3d): ...
    def ToFloatArray (self) -> Set(Single): ...
    def Remove (self, index : int, shrinkFaces : bool) -> bool: ...
    def Remove (self, indices : Iterable[int], shrinkFaces : bool) -> bool: ...
    def GetEnumerator (self) -> IEnumerator: ...
class MeshTopologyVertexList:
    @property
    def Count (self) -> int: ...
    @property
    def Item (self, index : int) -> Point3f: ...
    @Item.setter
    def Item (self, index : int, value : Point3f) -> None: ...
    def TopologyVertexIndex (self, vertexIndex : int) -> int: ...
    def MeshVertexIndices (self, topologyVertexIndex : int) -> Set(int): ...
    def IndicesFromFace (self, faceIndex : int) -> Set(int): ...
    def ConnectedTopologyVertices (self, topologyVertexIndex : int) -> Set(int): ...
    def ConnectedTopologyVertices (self, topologyVertexIndex : int, sorted : bool) -> Set(int): ...
    def SortEdges (self) -> bool: ...
    def SortEdges (self, topologyVertexIndex : int) -> bool: ...
    def IsHidden (self, topologyVertexIndex : int) -> bool: ...
    def ConnectedFaces (self, topologyVertexIndex : int) -> Set(int): ...
    def ConnectedEdgesCount (self, topologyVertexIndex : int) -> int: ...
    def ConnectedEdge (self, topologyVertexIndex : int, edgeAtVertexIndex : int) -> int: ...
    def ConnectedEdges (self, topologyVertexIndex : int) -> Set(int): ...
    def GetEnumerator (self) -> IEnumerator: ...
class MeshTopologyEdgeList:
    @property
    def Count (self) -> int: ...
    def GetTopologyVertices (self, topologyEdgeIndex : int) -> IndexPair: ...
    def GetConnectedFaces (self, topologyEdgeIndex : int) -> Set(int): ...
    def GetConnectedFaces (self, topologyEdgeIndex : int) -> Tuple[Set(int), Set(bool)]: ...
    def GetEdgesForFace (self, faceIndex : int) -> Set(int): ...
    def GetEdgesForFace (self, faceIndex : int) -> Tuple[Set(int), Set(bool)]: ...
    def GetEdgeIndex (self, topologyVertex1 : int, topologyVertex2 : int) -> int: ...
    def EdgeLine (self, topologyEdgeIndex : int) -> Line: ...
    def CollapseEdge (self, topologyEdgeIndex : int) -> bool: ...
    def SplitEdge (self, topologyEdgeIndex : int, t : float) -> bool: ...
    def SplitEdge (self, topologyEdgeIndex : int, point : Point3d) -> bool: ...
    def IsEdgeUnwelded (self, topologyEdgeIndex : int) -> bool: ...
    def IsSwappableEdge (self, topologyEdgeIndex : int) -> bool: ...
    def SwapEdge (self, topologyEdgeIndex : int) -> bool: ...
    def IsHidden (self, topologyEdgeIndex : int) -> bool: ...
    def IsNgonInterior (self, topologyEdgeIndex : int) -> bool: ...
class MeshVertexNormalList:
    @property
    def Count (self) -> int: ...
    @Count.setter
    def Count (self, value : int) -> None: ...
    @property
    def Capacity (self) -> int: ...
    @Capacity.setter
    def Capacity (self, value : int) -> None: ...
    @property
    def Item (self, index : int) -> Vector3f: ...
    @Item.setter
    def Item (self, index : int, value : Vector3f) -> None: ...
    def Clear (self) -> None: ...
    def Destroy (self) -> None: ...
    def Add (self, x : Single, y : Single, z : Single) -> int: ...
    def Add (self, x : float, y : float, z : float) -> int: ...
    def Add (self, normal : Vector3f) -> int: ...
    def Add (self, normal : Vector3d) -> int: ...
    def AddRange (self, normals : Set(Vector3f)) -> bool: ...
    def SetNormal (self, index : int, x : Single, y : Single, z : Single) -> bool: ...
    def SetNormal (self, index : int, x : float, y : float, z : float) -> bool: ...
    def SetNormal (self, index : int, normal : Vector3f) -> bool: ...
    def SetNormal (self, index : int, normal : Vector3d) -> bool: ...
    def SetNormals (self, normals : Set(Vector3f)) -> bool: ...
    def ToFloatArray (self) -> Set(Single): ...
    def ComputeNormals (self) -> bool: ...
    def UnitizeNormals (self) -> bool: ...
    def Flip (self) -> None: ...
    def GetEnumerator (self) -> IEnumerator: ...
class MeshFaceList:
    @property
    def Count (self) -> int: ...
    @Count.setter
    def Count (self, value : int) -> None: ...
    @property
    def QuadCount (self) -> int: ...
    @property
    def TriangleCount (self) -> int: ...
    @property
    def Capacity (self) -> int: ...
    @Capacity.setter
    def Capacity (self, value : int) -> None: ...
    def Clear (self) -> None: ...
    def Destroy (self) -> None: ...
    def AddFace (self, face : MeshFace) -> int: ...
    def AddFace (self, vertex1 : int, vertex2 : int, vertex3 : int) -> int: ...
    def AddFace (self, vertex1 : int, vertex2 : int, vertex3 : int, vertex4 : int) -> int: ...
    def AddFaces (self, faces : Iterable[MeshFace]) -> Set(int): ...
    def Insert (self, index : int, face : MeshFace) -> None: ...
    def SetFace (self, index : int, face : MeshFace) -> bool: ...
    def SetFace (self, index : int, vertex1 : int, vertex2 : int, vertex3 : int) -> bool: ...
    def SetFace (self, index : int, vertex1 : int, vertex2 : int, vertex3 : int, vertex4 : int) -> bool: ...
    def GetFace (self, index : int) -> MeshFace: ...
    def GetFaceAspectRatio (self, index : int) -> float: ...
    @property
    def Item (self, index : int) -> MeshFace: ...
    @Item.setter
    def Item (self, index : int, value : MeshFace) -> None: ...
    def GetFaceVertices (self, faceIndex : int) -> Tuple[bool, Point3f, Point3f, Point3f, Point3f]: ...
    def GetFaceBoundingBox (self, faceIndex : int) -> BoundingBox: ...
    def GetFaceCenter (self, faceIndex : int) -> Point3d: ...
    def AdjacentFaces (self, faceIndex : int) -> Set(int): ...
    def ToIntArray (self, asTriangles : bool) -> Set(int): ...
    def ToIntArray (self, asTriangles : bool, replacedIndices : List) -> Tuple[Set(int), List]: ...
    def DeleteFaces (self, faceIndexes : Iterable[int]) -> int: ...
    def DeleteFaces (self, faceIndexes : Iterable[int], compact : bool) -> int: ...
    def RemoveAt (self, index : int) -> None: ...
    def RemoveAt (self, index : int, compact : bool) -> None: ...
    def ConvertQuadsToTriangles (self) -> bool: ...
    def ConvertNonPlanarQuadsToTriangles (self, planarTolerance : float, angleToleranceRadians : float, splitMethod : int) -> int: ...
    def ConvertTrianglesToQuads (self, angleToleranceRadians : float, minimumDiagonalLengthRatio : float) -> bool: ...
    def CullDegenerateFaces (self) -> int: ...
    def IsHidden (self, faceIndex : int) -> bool: ...
    def HasNakedEdges (self, faceIndex : int) -> bool: ...
    def GetTopologicalVertices (self, faceIndex : int) -> Set(int): ...
    def GetClashingFacePairs (self, maxPairCount : int) -> Set(IndexPair): ...
    def GetConnectedFaces (self, faceIndex : int, angleRadians : float, greaterThanAngle : bool) -> Set(int): ...
    def GetConnectedFacesToEdges (self, startFaceIndex : int, treatNonmanifoldLikeUnwelded : bool) -> Set(int): ...
    def GetZeroAreaFaces (self) -> Tuple[bool, Set(int), Set(int)]: ...
    def RemoveZeroAreaFaces (self, fixedFaceCount : int) -> Tuple[int, int]: ...
    def GetDuplicateFaces (self) -> Set(int): ...
    def ExtractDuplicateFaces (self) -> Mesh: ...
    def ExtractFaces (self, faceIndices : Iterable[int]) -> Mesh: ...
    def GetEnumerator (self) -> IEnumerator: ...
class MeshNgonList:
    @property
    def Count (self) -> int: ...
    @Count.setter
    def Count (self, value : int) -> None: ...
    @property
    def UnsignedCount (self) -> UInt32: ...
    @UnsignedCount.setter
    def UnsignedCount (self, value : UInt32) -> None: ...
    def Clear (self) -> None: ...
    def AddNgon (self, ngon : MeshNgon) -> int: ...
    def AddNgons (self, ngons : Iterable[MeshNgon]) -> Set(int): ...
    def AddPlanarNgons (self, planarTolerance : float) -> int: ...
    def AddPlanarNgons (self, planarTolerance : float, minimumNgonVertexCount : int, minimumNgonFaceCount : int, allowHoles : bool) -> int: ...
    def NgonBoundaryVertexList (self, ngon : MeshNgon, bAppendStartPoint : bool) -> Set(Point3d): ...
    def Insert (self, index : int, ngon : MeshNgon) -> None: ...
    def SetNgon (self, index : int, ngon : MeshNgon) -> None: ...
    def GetNgon (self, index : int) -> MeshNgon: ...
    def NgonIndexFromFaceIndex (self, meshFaceIndex : int) -> int: ...
    @property
    def Item (self, index : int) -> MeshNgon: ...
    @Item.setter
    def Item (self, index : int, value : MeshNgon) -> None: ...
    def GetNgonBoundingBox (self, index : int) -> BoundingBox: ...
    def GetNgonBoundingBox (self, ngon : MeshNgon) -> BoundingBox: ...
    def GetNgonOuterEdgeCount (self, index : int) -> int: ...
    def GetNgonEdgeCount (self, index : int) -> int: ...
    def NgonHasHoles (self, index : int) -> bool: ...
    def GetNgonCenter (self, index : int) -> Point3d: ...
    def GetNgonCenter (self, ngon : MeshNgon) -> Point3d: ...
    def RemoveNgons (self, indices : Iterable[int]) -> int: ...
    def RemoveAt (self, index : int) -> None: ...
    def GetNgonBoundary (self, ngonFaceIndexList : Iterable[int]) -> Set(int): ...
    def IsValid (self, index : int) -> UInt32: ...
    def IsValid (self, index : int, textLog : TextLog) -> UInt32: ...
    def GetEnumerator (self) -> IEnumerator: ...
class MeshFaceNormalList:
    @property
    def Count (self) -> int: ...
    @Count.setter
    def Count (self, value : int) -> None: ...
    @property
    def Item (self, index : int) -> Vector3f: ...
    @Item.setter
    def Item (self, index : int, value : Vector3f) -> None: ...
    @property
    def Capacity (self) -> int: ...
    @Capacity.setter
    def Capacity (self, value : int) -> None: ...
    def Clear (self) -> None: ...
    def Destroy (self) -> None: ...
    def AddFaceNormal (self, x : Single, y : Single, z : Single) -> int: ...
    def AddFaceNormal (self, x : float, y : float, z : float) -> int: ...
    def AddFaceNormal (self, normal : Vector3d) -> int: ...
    def AddFaceNormal (self, normal : Vector3f) -> int: ...
    def SetFaceNormal (self, index : int, x : Single, y : Single, z : Single) -> bool: ...
    def SetFaceNormal (self, index : int, x : float, y : float, z : float) -> bool: ...
    def SetFaceNormal (self, index : int, normal : Vector3d) -> bool: ...
    def SetFaceNormal (self, index : int, normal : Vector3f) -> bool: ...
    def UnitizeFaceNormals (self) -> bool: ...
    def ComputeFaceNormals (self) -> bool: ...
    def GetEnumerator (self) -> IEnumerator: ...
class MeshVertexColorList:
    @property
    def Count (self) -> int: ...
    @Count.setter
    def Count (self, value : int) -> None: ...
    @property
    def Item (self, index : int) -> Color: ...
    @Item.setter
    def Item (self, index : int, value : Color) -> None: ...
    @property
    def Tag (self) -> MappingTag: ...
    @Tag.setter
    def Tag (self, value : MappingTag) -> None: ...
    def Clear (self) -> None: ...
    def Add (self, red : int, green : int, blue : int) -> int: ...
    def Add (self, color : Color) -> int: ...
    def SetColor (self, index : int, red : int, green : int, blue : int) -> bool: ...
    def SetColor (self, index : int, color : Color) -> bool: ...
    def SetColor (self, face : MeshFace, color : Color) -> bool: ...
    @property
    def Capacity (self) -> int: ...
    @Capacity.setter
    def Capacity (self, value : int) -> None: ...
    def CreateMonotoneMesh (self, baseColor : Color) -> bool: ...
    def SetColors (self, colors : Set(Color)) -> bool: ...
    def AppendColors (self, colors : Set(Color)) -> bool: ...
    def Destroy (self) -> None: ...
    def GetEnumerator (self) -> IEnumerator: ...
class MeshTextureCoordinateList:
    @property
    def Count (self) -> int: ...
    @Count.setter
    def Count (self, value : int) -> None: ...
    @property
    def Capacity (self) -> int: ...
    @Capacity.setter
    def Capacity (self, value : int) -> None: ...
    @property
    def Item (self, index : int) -> Point2f: ...
    @Item.setter
    def Item (self, index : int, value : Point2f) -> None: ...
    def Clear (self) -> None: ...
    def Add (self, s : Single, t : Single) -> int: ...
    def Add (self, s : float, t : float) -> int: ...
    def Add (self, tc : Point2f) -> int: ...
    def Add (self, tc : Point3d) -> int: ...
    def AddRange (self, textureCoordinates : Set(Point2f)) -> bool: ...
    def SetTextureCoordinate (self, index : int, s : Single, t : Single) -> bool: ...
    def SetTextureCoordinate (self, index : int, s : float, t : float) -> bool: ...
    def SetTextureCoordinate (self, index : int, tc : Point2f) -> bool: ...
    def SetTextureCoordinate (self, index : int, tc : Point3f) -> bool: ...
    def SetTextureCoordinates (self, textureCoordinates : Set(Point2f)) -> bool: ...
    def SetTextureCoordinates (self, mapping : TextureMapping) -> bool: ...
    def Destroy (self) -> None: ...
    def NormalizeTextureCoordinates (self) -> bool: ...
    def TransposeTextureCoordinates (self) -> bool: ...
    def ReverseTextureCoordinates (self, direction : int) -> bool: ...
    def ToFloatArray (self) -> Set(Single): ...
    def GetEnumerator (self) -> IEnumerator: ...
class MeshVertexStatusList:
    @property
    def Count (self) -> int: ...
    @Count.setter
    def Count (self, value : int) -> None: ...
    @property
    def HiddenCount (self) -> int: ...
    @property
    def Capacity (self) -> int: ...
    @Capacity.setter
    def Capacity (self, value : int) -> None: ...
    @property
    def Item (self, index : int) -> bool: ...
    @Item.setter
    def Item (self, index : int, value : bool) -> None: ...
    def Clear (self) -> None: ...
    def Add (self, hidden : bool) -> None: ...
    def AddRange (self, values : Iterable[bool]) -> None: ...
    def Destroy (self) -> None: ...
    def Contains (self, hidden : bool) -> bool: ...
    def CopyTo (self, array : Set(bool), arrayIndex : int) -> None: ...
    def GetEnumerator (self) -> IEnumerator: ...
class NurbsSurfacePointList:
    def EnsurePrivateCopy (self) -> None: ...
    @property
    def CountU (self) -> int: ...
    @property
    def CountV (self) -> int: ...
    def GetGrevillePoint (self, u : int, v : int) -> Point2d: ...
    def GetControlPoint (self, u : int, v : int) -> ControlPoint: ...
    def SetControlPoint (self, u : int, v : int, cp : ControlPoint) -> bool: ...
    def SetControlPoint (self, u : int, v : int, cp : Point3d) -> bool: ...
    def SetPoint (self, u : int, v : int, x : float, y : float, z : float) -> bool: ...
    def SetPoint (self, u : int, v : int, x : float, y : float, z : float, weight : float) -> bool: ...
    def SetPoint (self, u : int, v : int, point : Point3d) -> bool: ...
    def SetPoint (self, u : int, v : int, point : Point4d) -> bool: ...
    def SetPoint (self, u : int, v : int, point : Point3d, weight : float) -> bool: ...
    def GetPoint (self, u : int, v : int) -> Tuple[bool, Point3d]: ...
    def GetPoint (self, u : int, v : int) -> Tuple[bool, Point4d]: ...
    def SetWeight (self, u : int, v : int, weight : float) -> bool: ...
    def GetWeight (self, u : int, v : int) -> float: ...
    @property
    def PointSize (self) -> int: ...
    def UVNDirectionsAt (self, u : int, v : int) -> Tuple[bool, Vector3d, Vector3d, Vector3d]: ...
    def ValidateSpacing (self, closeTolerance : float, stackTolerance : float) -> Tuple[bool, Set(IndexPair), Set(IndexPair)]: ...
    def EpsilonEquals (self, other : NurbsSurfacePointList, epsilon : float) -> bool: ...
class NurbsSurfaceKnotList:
    @property
    def Count (self) -> int: ...
    @property
    def ClampedAtStart (self) -> bool: ...
    @property
    def ClampedAtEnd (self) -> bool: ...
    def SuperfluousKnot (self, start : bool) -> float: ...
    @property
    def Item (self, index : int) -> float: ...
    @Item.setter
    def Item (self, index : int, value : float) -> None: ...
    def EnsurePrivateCopy (self) -> None: ...
    def InsertKnot (self, value : float) -> bool: ...
    def InsertKnot (self, value : float, multiplicity : int) -> bool: ...
    def KnotMultiplicity (self, index : int) -> int: ...
    def CreateUniformKnots (self, knotSpacing : float) -> bool: ...
    def CreatePeriodicKnots (self, knotSpacing : float) -> bool: ...
    def RemoveMultipleKnots (self, minimumMultiplicity : int, maximumMultiplicity : int, tolerance : float) -> int: ...
    def RemoveKnots (self, index0 : int, index1 : int) -> bool: ...
    def RemoveKnotsAt (self, u : float, v : float) -> bool: ...
    def EpsilonEquals (self, other : NurbsSurfaceKnotList, epsilon : float) -> bool: ...
class SubDVertexList:
    @property
    def Count (self) -> int: ...
    @property
    def First (self) -> SubDVertex: ...
    def Find (self, id : UInt32) -> SubDVertex: ...
    def Find (self, id : int) -> SubDVertex: ...
    def Add (self, tag : SubDVertexTag, vertex : Point3d) -> SubDVertex: ...
class SubDEdgeList:
    @property
    def Count (self) -> int: ...
    def Find (self, id : UInt32) -> SubDEdge: ...
    def Find (self, id : int) -> SubDEdge: ...
    def GetEnumerator (self) -> IEnumerator: ...
    def Add (self, tag : SubDEdgeTag, v0 : SubDVertex, v1 : SubDVertex) -> SubDEdge: ...
class SubDFaceList:
    @property
    def Count (self) -> int: ...
    def Find (self, id : UInt32) -> SubDFace: ...
    def Find (self, id : int) -> SubDFace: ...
    def GetEnumerator (self) -> IEnumerator: ...
class NurbsCurveKnotList:
    @property
    def Count (self) -> int: ...
    @property
    def Item (self, index : int) -> float: ...
    @Item.setter
    def Item (self, index : int, value : float) -> None: ...
    def EnsurePrivateCopy (self) -> None: ...
    def InsertKnot (self, value : float) -> bool: ...
    def InsertKnot (self, value : float, multiplicity : int) -> bool: ...
    def KnotMultiplicity (self, index : int) -> int: ...
    def CreateUniformKnots (self, knotSpacing : float) -> bool: ...
    def CreatePeriodicKnots (self, knotSpacing : float) -> bool: ...
    @property
    def IsClampedStart (self) -> bool: ...
    @property
    def IsClampedEnd (self) -> bool: ...
    def ClampEnd (self, end : CurveEnd) -> bool: ...
    def SuperfluousKnot (self, start : bool) -> float: ...
    def RemoveMultipleKnots (self, minimumMultiplicity : int, maximumMultiplicity : int, tolerance : float) -> int: ...
    def RemoveKnots (self, index0 : int, index1 : int) -> bool: ...
    def RemoveKnotAt (self, t : float) -> bool: ...
    def EpsilonEquals (self, other : NurbsCurveKnotList, epsilon : float) -> bool: ...
    def IndexOf (self, item : float) -> int: ...
    def Contains (self, item : float) -> bool: ...
    def CopyTo (self, array : Set(float), arrayIndex : int) -> None: ...
class NurbsCurvePointList:
    def EnsurePrivateCopy (self) -> None: ...
    @property
    def Count (self) -> int: ...
    @property
    def Item (self, index : int) -> ControlPoint: ...
    @Item.setter
    def Item (self, index : int, value : ControlPoint) -> None: ...
    @property
    def ControlPolygonLength (self) -> float: ...
    def ControlPolygon (self) -> Polyline: ...
    def ChangeEndWeights (self, w0 : float, w1 : float) -> bool: ...
    def MakeRational (self) -> bool: ...
    def MakeNonRational (self) -> bool: ...
    def SetPoint (self, index : int, x : float, y : float, z : float) -> bool: ...
    def SetPoint (self, index : int, x : float, y : float, z : float, weight : float) -> bool: ...
    def SetPoint (self, index : int, point : Point3d) -> bool: ...
    def SetPoint (self, index : int, point : Point4d) -> bool: ...
    def SetPoint (self, index : int, point : Point3d, weight : float) -> bool: ...
    def GetPoint (self, index : int) -> Tuple[bool, Point3d]: ...
    def GetPoint (self, index : int) -> Tuple[bool, Point4d]: ...
    def SetWeight (self, index : int, weight : float) -> bool: ...
    def GetWeight (self, index : int) -> float: ...
    @property
    def PointSize (self) -> int: ...
    def ValidateSpacing (self, closeTolerance : float, stackTolerance : float) -> Tuple[bool, Set(int), Set(int)]: ...
    def UVNDirectionsAt (self, index : int) -> Tuple[bool, Vector3d, Vector3d, Vector3d]: ...
    def EpsilonEquals (self, other : NurbsCurvePointList, epsilon : float) -> bool: ...
    def IndexOf (self, item : ControlPoint) -> int: ...
    def Contains (self, item : ControlPoint) -> bool: ...
    def CopyTo (self, array : Set(ControlPoint), arrayIndex : int) -> None: ...
